@@ -83,7 +83,7 @@ time_zones = load_time_zones("/usr/share/zoneinfo")
 
 
 class DucklingAnnotator(AnnotatorBase):
-    """[Duckling](https://github.com/facebook/duckling) annotator.
+    __doc__ = """[Duckling](https://github.com/facebook/duckling) annotator.
     #need-segments
     #languages:""" + SUPPORTED_LANGUAGES
 
