@@ -1,4 +1,6 @@
+import json
 from datetime import datetime, timedelta
+from pathlib import Path
 from typing import List
 
 from dirty_equals import HasLen, HasAttributes, IsList, IsPartialDict, IsNow, IsDatetime
@@ -50,3 +52,20 @@ def test_duckling():
                                                                                       enforce_tz=False))),
         HasAttributes(labelName="money", properties=IsPartialDict(dim='amount-of-money', unit='EUR', value=15.5))
     )
+
+
+def test_duckling_file():
+    testdir = Path(__file__).parent
+    source = Path(testdir, "data/sens_arret-document-JURITEXT000024487667.json")
+    annotator = DucklingAnnotator()
+    parameters = DucklingParameters()
+    parameters.mapping = {
+        "datetime": ["time"],
+        "money": ["amount-of-money"]
+    }
+    with source.open("r") as fin:
+        docs = json.load(fin)
+        jdocs = [Document(**doc) for doc in docs]
+        jdocs: List[Document] = annotator.annotate(jdocs, parameters)
+        jdoc0 = jdocs[0]
+        assert jdoc0.annotations == HasLen(75)
